@@ -29,17 +29,17 @@ def verify_credentials(func):
 
 class Account:
 
-    def __init__(self, profile='default', hq='https://detect.prelude.org', keychain_location=os.path.join(Path.home(), '.prelude', 'keychain.ini')):
+    def __init__(self, profile='default', hq='https://api.preludesecurity.com', keychain_location=os.path.join(Path.home(), '.prelude', 'keychain.ini')):
         self.profile = profile
         self.hq = hq
         self.headers = dict()
         self.keychain_location = keychain_location
 
-    def configure(self, account_id, token, hq='https://detect.prelude.org', profile='default'):
+    def configure(self, account_id, token, hq='https://api.preludesecurity.com', profile='default'):
         cfg = self._merge_configs(self.read_keychain_config(hq, profile), self.generate_config(account_id, token, hq, profile))
         self.write_keychain_config(cfg=cfg)
 
-    def read_keychain_config(self, hq='https://detect.prelude.org', profile='default'):
+    def read_keychain_config(self, hq='https://api.preludesecurity.com', profile='default'):
         if not exists(self.keychain_location):
             head, _ = os.path.split(Path(self.keychain_location))
             Path(head).mkdir(parents=True, exist_ok=True)
